@@ -1,7 +1,9 @@
+import copy
 import json
 from collections import defaultdict
 from pathlib import Path
 from typing import Set, Dict, Any, List, Type, Optional
+
 import tensorflow as tf  # type: ignore
 from tensorflow.python.keras.utils.generic_utils import func_load  # type: ignore
 
@@ -143,7 +145,7 @@ class KerasJsonModelImport:
         if layer_metadata is None:
             if layer_json['class_name'] in self.custom_layers:
                 layer_metadata = {
-                    'type': 'UserCustomLayer',
+                    'type': 'CustomLayer',
                     'name': layer_json['class_name']
                 }
         return layer_metadata
@@ -278,7 +280,8 @@ class KerasJsonModelImport:
 
     def handle_input_layer(self, layer: Dict[str, Any]):
         if 'Dataset' not in self.nodes_cache:
-            self.nodes_cache['Dataset'] = NodeResponse(id=str(self.id), name='Dataset', data=DATASET_DATA)
+            dataset_copy = copy.deepcopy(DATASET_DATA)
+            self.nodes_cache['Dataset'] = NodeResponse(id=str(self.id), name='Dataset', data=dataset_copy)
             self.id += 1
 
         dataset = self.nodes_cache['Dataset']
